package
Version:
v0.2.4
Opens a new window with list of versions in this module.
Published: Feb 10, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Changed bool
Reversed bool
Sorted bool
Since string
PulumiVersion string `mapstructure:"pulumi-version"`
}
NewConfig reads in config file and ENV variables if set.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.