git

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct{}

func NewClient

func NewClient() *Client

func (Client) Diff

func (g Client) Diff(baseRef string) ([]string, error)

Diff returns a list of files changed since the baseRef

func (Client) SearchFiles

func (g Client) SearchFiles(cwd, pattern string) ([]string, error)

SearchFiles searches for files matching the pattern in the working directory

Jump to